@@ -3,6 +3,7 @@ MCAk <- function(data, nclus = 3, ndim = 2, alphak = .5, nstart = 100, smartStar
   
   group={}
   data = data.frame(data,stringsAsFactors = TRUE)
+  odata = data
   if (inboot == FALSE) {
     data=as.data.frame(lapply(data,as.factor),stringsAsFactors = TRUE)
     lab1a=names(data)
@@ -71,7 +72,7 @@ MCAk <- function(data, nclus = 3, ndim = 2, alphak = .5, nstart = 100, smartStar
     out$cluster = cluster
     out$criterion = 1 # criterion
     out$size=as.integer(aa)  #round((table(cluster)/sum( table(cluster)))*100,digits=1)
-    out$odata=data.frame(lapply(data.frame(data),factor),stringsAsFactors = TRUE)
+    out$odata=data.frame(odata, stringsAsFactors = TRUE)#data.frame(lapply(data.frame(data),factor),stringsAsFactors = TRUE)
     out$nstart = nstart
     class(out)="clusmca"
     return(out)
@@ -251,7 +252,7 @@ MCAk <- function(data, nclus = 3, ndim = 2, alphak = .5, nstart = 100, smartStar
     out$cluster = cluster #as.numeric(index) # cluster membership
     out$criterion = f # criterion
     out$size = as.integer(aa)  #round((table(cluster)/sum( table(cluster)))*100,digits=1)
-    out$odata = data.frame(lapply(data.frame(data),factor),stringsAsFactors = TRUE)
+    out$odata = data.frame(odata, stringsAsFactors = TRUE)#data.frame(lapply(data.frame(data),factor),stringsAsFactors = TRUE)
     out$nstart = nstart
     class(out) = "clusmca"
     return(out)
